SickChill Contrib
=====
Stuff contributed to SickChill, or included of users leisure

## What will you find in here?
 - Scripts
 - Links to other repositories we think make your life better
 - Custom themes
 - Other things that may come in handy

